@@ -15,12 +15,10 @@
  */
 
 #include "transfer.h"
-#include "captchadialog.h"
 #include "decaptchaplugin.h"
 #include "decaptchapluginmanager.h"
 #include "definitions.h"
 #include "logger.h"
-#include "pluginsettingsdialog.h"
 #include "recaptchaplugin.h"
 #include "recaptchapluginmanager.h"
 #include "serviceplugin.h"
@@ -31,6 +29,7 @@
 #include <QBuffer>
 #include <QDir>
 #include <QFile>
+#include <QImage>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QSettings>
@@ -47,19 +46,19 @@ Transfer::Transfer(QObject *parent) :
     m_reply(0),
     m_file(0),
     m_timer(0),
-    m_captchaDialog(0),
-    m_settingsDialog(0),
     m_priority(NormalPriority),
     m_lastBytesTransferred(0),
     m_size(0),
     m_speed(0),
     m_status(Paused),
+    m_requestMethod("GET"),
     m_servicePluginIcon(DEFAULT_ICON),
-    m_servicePluginName(tr("Unknown")),
+    m_customCommandOverrideEnabled(false),
+    m_usePlugins(true),
     m_reportCaptchaError(false),
     m_metadataSet(false),
     m_redirects(0),
-    m_waitTime(0)
+    m_timeRemaining(0)
 {
 }
 
@@ -71,8 +70,12 @@ QVariant Transfer::data(int role) const {
         return captchaImage();
     case CaptchaTimeoutRole:
         return captchaTimeout();
+    case CaptchaTimeoutStringRole:
+        return captchaTimeoutString();
     case CustomCommandRole:
         return customCommand();
+    case CustomCommandOverrideEnabledRole:
+        return customCommandOverrideEnabled();
     case DownloadPathRole:
         return downloadPath();
     case ErrorStringRole:
@@ -90,6 +93,8 @@ QVariant Transfer::data(int role) const {
         return pluginId();
     case PluginNameRole:
         return pluginName();
+    case PostDataRole:
+        return postData();
     case PriorityRole:
         return priority();
     case PriorityStringRole:
@@ -102,6 +107,14 @@ QVariant Transfer::data(int role) const {
         return requestedSettings();
     case RequestedSettingsTimeoutRole:
         return requestedSettingsTimeout();
+    case RequestedSettingsTimeoutStringRole:
+        return requestedSettingsTimeoutString();
+    case RequestedSettingsTitleRole:
+        return requestedSettingsTitle();
+    case RequestHeadersRole:
+        return requestHeaders();
+    case RequestMethodRole:
+        return requestMethod();
     case SizeRole:
         return size();
     case SpeedRole:
@@ -116,6 +129,8 @@ QVariant Transfer::data(int role) const {
         return fileSuffix();
     case UrlRole:
         return url();
+    case UsePluginsRole:
+        return usePlugins();
     case WaitTimeRole:
         return waitTime();
     case WaitTimeStringRole:
@@ -132,6 +147,9 @@ bool Transfer::setData(int role, const QVariant &value) {
     case CustomCommandRole:
         setCustomCommand(value.toString());
         return true;
+    case CustomCommandOverrideEnabledRole:
+        setCustomCommandOverrideEnabled(value.toBool());
+        return true;
     case DownloadPathRole:
         setDownloadPath(value.toString());
         return true;
@@ -145,11 +163,20 @@ bool Transfer::setData(int role, const QVariant &value) {
     case IdRole:
         setId(value.toString());
         return true;
+    case PostDataRole:
+        setPostData(value.toByteArray());
+        return true;
     case PriorityRole:
         setPriority(TransferItem::Priority(value.toInt()));
         return true;
     case RequestedSettingsRole:
         return submitSettingsResponse(value.toMap());
+    case RequestHeadersRole:
+        setRequestHeaders(value.toMap());
+        return true;
+    case RequestMethodRole:
+        setRequestMethod(value.toByteArray());
+        return true;
     case StatusRole:
         switch (value.toInt()) {
         case Queued:
@@ -168,6 +195,9 @@ bool Transfer::setData(int role, const QVariant &value) {
     case UrlRole:
         setUrl(value.toString());
         return true;
+    case UsePluginsRole:
+        setUsePlugins(value.toBool());
+        return true;
     default:
         return TransferItem::setData(role, value);
     }
@@ -178,7 +208,9 @@ QMap<int, QVariant> Transfer::itemData() const {
     map[BytesTransferredRole] = bytesTransferred();
     map[CaptchaImageRole] = captchaImage();
     map[CaptchaTimeoutRole] = captchaTimeout();
+    map[CaptchaTimeoutStringRole] = captchaTimeoutString();
     map[CustomCommandRole] = customCommand();
+    map[CustomCommandOverrideEnabledRole] = customCommandOverrideEnabled();
     map[DownloadPathRole] = downloadPath();
     map[ErrorStringRole] = errorString();
     map[FileNameRole] = fileName();
@@ -187,12 +219,17 @@ QMap<int, QVariant> Transfer::itemData() const {
     map[PluginIconPathRole] = pluginIconPath();
     map[PluginIdRole] = pluginId();
     map[PluginNameRole] = pluginName();
+    map[PostDataRole] = postData();
     map[PriorityRole] = priority();
     map[PriorityStringRole] = priorityString();
     map[ProgressRole] = progress();
     map[ProgressStringRole] = progressString();
     map[RequestedSettingsRole] = requestedSettings();
     map[RequestedSettingsTimeoutRole] = requestedSettingsTimeout();
+    map[RequestedSettingsTimeoutStringRole] = requestedSettingsTimeoutString();
+    map[RequestedSettingsTitleRole] = requestedSettingsTitle();
+    map[RequestHeadersRole] = requestHeaders();
+    map[RequestMethodRole] = requestMethod();
     map[SizeRole] = size();
     map[SpeedRole] = speed();
     map[SpeedStringRole] = speedString();
@@ -200,6 +237,7 @@ QMap<int, QVariant> Transfer::itemData() const {
     map[StatusStringRole] = statusString();
     map[SuffixRole] = fileSuffix();
     map[UrlRole] = url();
+    map[UsePluginsRole] = usePlugins();
     map[WaitTimeRole] = waitTime();
     map[WaitTimeStringRole] = waitTimeString();
     return map;
@@ -210,7 +248,9 @@ QVariantMap Transfer::itemDataWithRoleNames() const {
     map[roleNames().value(BytesTransferredRole)] = bytesTransferred();
     map[roleNames().value(CaptchaImageRole)] = captchaImage();
     map[roleNames().value(CaptchaTimeoutRole)] = captchaTimeout();
+    map[roleNames().value(CaptchaTimeoutStringRole)] = captchaTimeoutString();
     map[roleNames().value(CustomCommandRole)] = customCommand();
+    map[roleNames().value(CustomCommandOverrideEnabledRole)] = customCommandOverrideEnabled();
     map[roleNames().value(DownloadPathRole)] = downloadPath();
     map[roleNames().value(ErrorStringRole)] = errorString();
     map[roleNames().value(FileNameRole)] = fileName();
@@ -220,12 +260,17 @@ QVariantMap Transfer::itemDataWithRoleNames() const {
     map[roleNames().value(PluginIconPathRole)] = pluginIconPath();
     map[roleNames().value(PluginIdRole)] = pluginId();
     map[roleNames().value(PluginNameRole)] = pluginName();
+    map[roleNames().value(PostDataRole)] = postData();
     map[roleNames().value(PriorityRole)] = priority();
     map[roleNames().value(PriorityStringRole)] = priorityString();
     map[roleNames().value(ProgressRole)] = progress();
     map[roleNames().value(ProgressStringRole)] = progressString();
     map[roleNames().value(RequestedSettingsRole)] = requestedSettings();
     map[roleNames().value(RequestedSettingsTimeoutRole)] = requestedSettingsTimeout();
+    map[roleNames().value(RequestedSettingsTimeoutStringRole)] = requestedSettingsTimeoutString();
+    map[roleNames().value(RequestedSettingsTitleRole)] = requestedSettingsTitle();
+    map[roleNames().value(RequestHeadersRole)] = requestHeaders();
+    map[roleNames().value(RequestMethodRole)] = requestMethod();
     map[roleNames().value(SizeRole)] = size();
     map[roleNames().value(SpeedRole)] = speed();
     map[roleNames().value(SpeedStringRole)] = speedString();
@@ -233,6 +278,7 @@ QVariantMap Transfer::itemDataWithRoleNames() const {
     map[roleNames().value(StatusStringRole)] = statusString();
     map[roleNames().value(SuffixRole)] = fileSuffix();
     map[roleNames().value(UrlRole)] = url();
+    map[roleNames().value(UsePluginsRole)] = usePlugins();
     map[roleNames().value(WaitTimeRole)] = waitTime();
     map[roleNames().value(WaitTimeStringRole)] = waitTimeString();
     return map;
@@ -290,6 +336,17 @@ void Transfer::setCustomCommand(const QString &c) {
     }
 }
 
+bool Transfer::customCommandOverrideEnabled() const {
+    return m_customCommandOverrideEnabled;
+}
+
+void Transfer::setCustomCommandOverrideEnabled(bool enabled) {
+    if (enabled != customCommandOverrideEnabled()) {
+        m_customCommandOverrideEnabled = enabled;
+        emit dataChanged(this, CustomCommandOverrideEnabledRole);
+    }
+}
+
 QString Transfer::downloadPath() const {
     return m_downloadPath;
 }
@@ -361,12 +418,8 @@ QByteArray Transfer::captchaImage() const {
 void Transfer::setCaptchaImage(const QImage &image) {
     QByteArray ba;
     QBuffer buffer(&ba);
-
-    if (buffer.open(QBuffer::WriteOnly)) {
-        image.save(&buffer);
-        buffer.close();
-    }
-
+    buffer.open(QBuffer::WriteOnly);
+    image.save(&buffer, "JPEG");
     m_captchaImageData = ba.toBase64();
     emit dataChanged(this, CaptchaImageRole);
 }
@@ -379,11 +432,29 @@ void Transfer::clearCaptchaImage() {
 }
 
 int Transfer::captchaTimeout() const {
+    return status() == AwaitingCaptchaResponse ? m_timeRemaining : 0;
+}
+
+QString Transfer::captchaTimeoutString() const {
+    return Utils::formatMSecs(captchaTimeout());
+}
+
+void Transfer::updateCaptchaTimeout() {
     switch (status()) {
-    case Transfer::AwaitingCaptchaResponse:
-        return m_captchaDialog.isNull() ? 0 : m_captchaDialog->timeRemaining();
+    case AwaitingCaptchaResponse:
+        m_timeRemaining -= m_timer->interval();
+        emit dataChanged(this, CaptchaTimeoutRole);
+        
+        if (m_timeRemaining <= 0) {
+            stopWaitTimer();
+            setErrorString(tr("No captcha response"));
+            setStatus(Failed);
+        }
+        
+        break;
     default:
-        return 0;
+        stopWaitTimer();
+        break;
     }
 }
 
@@ -431,6 +502,28 @@ void Transfer::setPluginName(const QString &n) {
     }
 }
 
+bool Transfer::usePlugins() const {
+    return m_usePlugins;
+}
+
+void Transfer::setUsePlugins(bool enabled) {
+    if (enabled != usePlugins()) {
+        m_usePlugins = enabled;
+        emit dataChanged(this, UsePluginsRole);
+    }
+}
+
+QString Transfer::postData() const {
+    return m_postData;
+}
+
+void Transfer::setPostData(const QString &data) {
+    if (data != postData()) {
+        m_postData = data;
+        emit dataChanged(this, PostDataRole);
+    }
+}
+
 TransferItem::Priority Transfer::priority() const {
     return m_priority;
 }
@@ -502,15 +595,19 @@ QVariantList Transfer::requestedSettings() const {
     return m_requestedSettings;
 }
 
-void Transfer::setRequestedSettings(const QVariantList &settings) {
+void Transfer::setRequestedSettings(const QString &title, const QVariantList &settings) {
+    m_requestedSettingsTitle = title;
     m_requestedSettings = settings;
     emit dataChanged(this, RequestedSettingsRole);
+    emit dataChanged(this, RequestedSettingsTitleRole);
 }
 
 void Transfer::clearRequestedSettings() {
     if (!m_requestedSettings.isEmpty()) {
+        m_requestedSettingsTitle.clear();
         m_requestedSettings.clear();
         emit dataChanged(this, RequestedSettingsRole);
+        emit dataChanged(this, RequestedSettingsTitleRole);
     }
 }
 
@@ -519,12 +616,67 @@ int Transfer::requestedSettingsTimeout() const {
     case AwaitingDecaptchaSettingsResponse:
     case AwaitingRecaptchaSettingsResponse:
     case AwaitingServiceSettingsResponse:
-        return m_settingsDialog.isNull() ? 0 : m_settingsDialog->timeRemaining();
+        return m_timeRemaining;
     default:
         return 0;
     }
 }
 
+QString Transfer::requestedSettingsTimeoutString() const {
+    return Utils::formatMSecs(requestedSettingsTimeout());
+}
+
+QString Transfer::requestedSettingsTitle() const {
+    return m_requestedSettingsTitle;
+}
+
+void Transfer::updateRequestedSettingsTimeout() {
+    switch (status()) {
+    case AwaitingDecaptchaSettingsResponse:
+    case AwaitingRecaptchaSettingsResponse:
+    case AwaitingServiceSettingsResponse:
+        m_timeRemaining -= m_timer->interval();
+        emit dataChanged(this, RequestedSettingsTimeoutRole);
+        
+        if (m_timeRemaining <= 0) {
+            stopWaitTimer();
+            setErrorString(tr("No settings response"));
+            setStatus(Failed);
+        }
+        
+        break;
+    default:
+        stopWaitTimer();
+        break;
+    }
+}
+
+QVariantMap Transfer::requestHeaders() const {
+    return m_requestHeaders;
+}
+
+void Transfer::setRequestHeaders(const QVariantMap &headers) {
+    m_requestHeaders = headers;
+    emit dataChanged(this, RequestHeadersRole);
+}
+
+QString Transfer::requestMethod() const {
+    return m_requestMethod;
+}
+
+void Transfer::setRequestMethod(const QString &method) {
+    if (method != requestMethod()) {
+        if (method.isEmpty()) {
+            m_requestMethod = QString("GET");
+        }
+        else {
+            m_requestMethod = method.toUpper();
+        }
+        
+        emit dataChanged(this, RequestMethodRole);
+    }
+}
+
 TransferItem::Status Transfer::status() const {
     return m_status;
 }
@@ -560,6 +712,12 @@ QString Transfer::statusString() const {
         return QString("%1: %2").arg(TransferItem::statusString(WaitingInactive)).arg(waitTimeString());
     case WaitingActive:
         return QString("%1: %2").arg(TransferItem::statusString(WaitingActive)).arg(waitTimeString());
+    case AwaitingCaptchaResponse:
+        return QString("%1: %2").arg(TransferItem::statusString(AwaitingCaptchaResponse)).arg(captchaTimeoutString());
+    case AwaitingDecaptchaSettingsResponse:
+    case AwaitingRecaptchaSettingsResponse:
+    case AwaitingServiceSettingsResponse:
+        return QString("%1: %2").arg(TransferItem::statusString(status())).arg(requestedSettingsTimeoutString());
     default:
         return TransferItem::statusString(status());
     }
@@ -601,7 +759,7 @@ void Transfer::setUrl(const QString &u) {
 }
 
 int Transfer::waitTime() const {
-    return m_waitTime;
+    return m_timeRemaining;
 }
 
 QString Transfer::waitTimeString() const {
@@ -612,10 +770,10 @@ void Transfer::updateWaitTime() {
     switch (status()) {
     case WaitingActive:
     case WaitingInactive:
-        m_waitTime -= m_timer->interval();
+        m_timeRemaining -= m_timer->interval();
         emit dataChanged(this, WaitTimeRole);
         
-        if (m_waitTime <= 0) {
+        if (m_timeRemaining <= 0) {
             stopWaitTimer();
             
             if (status() == WaitingInactive) {
@@ -641,6 +799,11 @@ bool Transfer::queue() {
 
 bool Transfer::start() {
     if (canStart()) {
+        if (!usePlugins()) {
+            startDownload();
+            return true;
+        }
+        
         if (initServicePlugin()) {
             setStatus(Connecting);
             m_servicePlugin->getDownloadRequest(url());
@@ -779,15 +942,20 @@ bool Transfer::cancel(bool deleteFiles) {
 
 void Transfer::restore(const QSettings &settings) {
     setCustomCommand(settings.value("customCommand").toString());
+    setCustomCommandOverrideEnabled(settings.value("customCommandOverrideEnabled", false).toBool());
     setDownloadPath(settings.value("downloadPath").toString());
     setErrorString(settings.value("errorString").toString());
     setFileName(settings.value("fileName").toString());
     setId(settings.value("id").toString());
-    setPriority(TransferItem::Priority(settings.value("priority").toInt()));
+    setPostData(settings.value("postData").toByteArray());
+    setPriority(TransferItem::Priority(settings.value("priority", NormalPriority).toInt()));
+    setRequestHeaders(settings.value("requestHeaders").toMap());
+    setRequestMethod(settings.value("requestMethod").toByteArray());
     setSize(qMax(qlonglong(0), settings.value("size").toLongLong()));
     setUrl(settings.value("url").toString());
+    setUsePlugins(settings.value("usePlugins", true).toBool());
 
-    const TransferItem::Status status = TransferItem::Status(settings.value("status").toInt());
+    const TransferItem::Status status = TransferItem::Status(settings.value("status", Paused).toInt());
 
     switch (status) {
     case Paused:
@@ -803,13 +971,18 @@ void Transfer::restore(const QSettings &settings) {
 
 void Transfer::save(QSettings &settings) {
     settings.setValue("customCommand", customCommand());
+    settings.setValue("customCommandOverrideEnabled", customCommandOverrideEnabled());
     settings.setValue("downloadPath", downloadPath());
     settings.setValue("errorString", errorString());
     settings.setValue("fileName", fileName());
     settings.setValue("id", id());
+    settings.setValue("postData", postData());
     settings.setValue("priority", TransferItem::Priority(priority()));
+    settings.setValue("requestHeaders", requestHeaders());
+    settings.setValue("requestMethod", requestMethod());
     settings.setValue("size", size());
     settings.setValue("url", url());
+    settings.setValue("usePlugins", usePlugins());
 
     switch (status()) {
     case Paused:
@@ -1068,33 +1241,19 @@ bool Transfer::openFile() {
     return m_file->open(QFile::WriteOnly | QFile::Append);
 }
 
-void Transfer::openCaptchaDialog(const QImage &image) {
-    CaptchaDialog dialog;
-    m_captchaDialog = &dialog;
-    dialog.setImage(image);
-    connect(this, SIGNAL(dataChanged(TransferItem*, int)), &dialog, SLOT(reject()));
-    
-    if (dialog.exec() == QDialog::Accepted) {
-        submitCaptchaResponse(dialog.response());
-    }
-    else if (status() == AwaitingCaptchaResponse) {
-        setErrorString(tr("No captcha response"));
-        setStatus(Failed);
-    }
-}
-
 void Transfer::startSpeedTimer() {
     m_speedTime.start();
 }
 
-void Transfer::startWaitTimer() {
+void Transfer::startWaitTimer(int msecs, const char* slot) {
     if (!m_timer) {
         m_timer = new QTimer(this);
         m_timer->setInterval(1000);
     }
-
+    
+    m_timeRemaining = msecs;
     disconnect(m_timer, 0, this, 0);
-    connect(m_timer, SIGNAL(timeout()), this, SLOT(updateWaitTime()));
+    connect(m_timer, SIGNAL(timeout()), this, slot);
     m_timer->start();
 }
 
@@ -1110,6 +1269,47 @@ void Transfer::stopWaitTimer() {
     }
 }
 
+void Transfer::startDownload() {
+    Logger::log(QString("Transfer::startDownload(). URL: %1, Method: %2").arg(url()).arg(requestMethod()));
+    m_redirects = 0;
+    m_metadataSet = false;
+    initNetworkAccessManager();
+    
+    QNetworkRequest request(url());
+    QMapIterator<QString, QVariant> iterator(requestHeaders());
+    
+    while (iterator.hasNext()) {
+        iterator.next();
+        request.setRawHeader(iterator.key().toUtf8(), iterator.value().toByteArray());
+    }
+
+    if (bytesTransferred() > 0) {
+        Logger::log("Transfer::startDownload(). Setting 'Range' header to " + QString::number(bytesTransferred()));
+        request.setRawHeader("Range", "bytes=" + QByteArray::number(bytesTransferred()) + "-");
+    }
+
+    if (postData().isEmpty()) {
+        setStatus(Downloading);
+        startSpeedTimer();
+        m_reply = m_nam->sendCustomRequest(request, requestMethod().toUtf8());
+        connect(m_reply, SIGNAL(finished()), this, SLOT(onReplyFinished()));
+        connect(m_reply, SIGNAL(metaDataChanged()), this, SLOT(onReplyMetaDataChanged()));
+        connect(m_reply, SIGNAL(readyRead()), this, SLOT(onReplyReadyRead()));
+    }
+    else {
+        setStatus(Downloading);
+        startSpeedTimer();
+        QBuffer *buffer = new QBuffer;
+        buffer->setData(postData().toUtf8());
+        buffer->open(QBuffer::ReadOnly);
+        m_reply = m_nam->sendCustomRequest(request, requestMethod().toUtf8(), buffer);
+        buffer->setParent(m_reply);
+        connect(m_reply, SIGNAL(finished()), this, SLOT(onReplyFinished()));
+        connect(m_reply, SIGNAL(metaDataChanged()), this, SLOT(onReplyMetaDataChanged()));
+        connect(m_reply, SIGNAL(readyRead()), this, SLOT(onReplyReadyRead()));
+    }
+}
+
 void Transfer::followRedirect(const QUrl &url) {
     Logger::log("Transfer::followRedirect(): " + url.toString());
     m_redirects++;
@@ -1147,9 +1347,9 @@ void Transfer::onCaptchaReady(const QString &challenge, const QImage &image) {
     }
 
     m_reportCaptchaError = false;
-    setStatus(AwaitingCaptchaResponse);
+    startWaitTimer(CAPTCHA_TIMEOUT, SLOT(updateCaptchaTimeout()));
     setCaptchaImage(image);
-    openCaptchaDialog(image);
+    setStatus(AwaitingCaptchaResponse);
 }
 
 void Transfer::onCaptchaRequest(const QString &recaptchaPluginId, const QString &recaptchaKey,
@@ -1199,9 +1399,9 @@ void Transfer::onDownloadRequest(QNetworkRequest request, const QByteArray &meth
     m_redirects = 0;
     m_metadataSet = false;
     initNetworkAccessManager();
-
+    
     if (bytesTransferred() > 0) {
-        Logger::log("Transfer::onDownloadRequest(). Setting 'Range' header to " + QString::number(bytesTransferred()));
+        Logger::log("Transfer::startDownload(). Setting 'Range' header to " + QString::number(bytesTransferred()));
         request.setRawHeader("Range", "bytes=" + QByteArray::number(bytesTransferred()) + "-");
     }
 
@@ -1228,8 +1428,7 @@ void Transfer::onDownloadRequest(QNetworkRequest request, const QByteArray &meth
 }
 
 void Transfer::onWaitRequest(int msecs, bool isLongDelay) {
-    m_waitTime = msecs;
-    startWaitTimer();
+    startWaitTimer(msecs, SLOT(updateWaitTime()));
 
     if (isLongDelay) {
         setStatus(WaitingInactive);
@@ -1241,56 +1440,23 @@ void Transfer::onWaitRequest(int msecs, bool isLongDelay) {
 
 void Transfer::onDecaptchaSettingsRequest(const QString &title, const QVariantList &settings, const QByteArray &callback) {
     m_callback = callback;
-    setRequestedSettings(settings);
+    startWaitTimer(CAPTCHA_TIMEOUT, SLOT(updateRequestedSettingsTimeout()));
+    setRequestedSettings(title, settings);
     setStatus(AwaitingDecaptchaSettingsResponse);
-    PluginSettingsDialog dialog(settings);
-    m_settingsDialog = &dialog;
-    dialog.setWindowTitle(title);
-    connect(this, SIGNAL(dataChanged(TransferItem*, int)), &dialog, SLOT(reject()));
-    
-    if (dialog.exec() == QDialog::Accepted) {
-        submitSettingsResponse(dialog.settings());
-    }
-    else if (status() == AwaitingDecaptchaSettingsResponse) {
-        setErrorString(tr("No settings response"));
-        setStatus(Failed);
-    }
 }
 
 void Transfer::onRecaptchaSettingsRequest(const QString &title, const QVariantList &settings, const QByteArray &callback) {
     m_callback = callback;
-    setRequestedSettings(settings);
+    startWaitTimer(CAPTCHA_TIMEOUT, SLOT(updateRequestedSettingsTimeout()));
+    setRequestedSettings(title, settings);
     setStatus(AwaitingRecaptchaSettingsResponse);
-    PluginSettingsDialog dialog(settings);
-    m_settingsDialog = &dialog;
-    dialog.setWindowTitle(title);
-    connect(this, SIGNAL(dataChanged(TransferItem*, int)), &dialog, SLOT(reject()));
-    
-    if (dialog.exec() == QDialog::Accepted) {
-        submitSettingsResponse(dialog.settings());
-    }
-    else if (status() == AwaitingRecaptchaSettingsResponse) {
-        setErrorString(tr("No settings response"));
-        setStatus(Failed);
-    }
 }
 
 void Transfer::onServiceSettingsRequest(const QString &title, const QVariantList &settings, const QByteArray &callback) {
     m_callback = callback;
-    setRequestedSettings(settings);
+    startWaitTimer(CAPTCHA_TIMEOUT, SLOT(updateRequestedSettingsTimeout()));
+    setRequestedSettings(title, settings);
     setStatus(AwaitingServiceSettingsResponse);
-    PluginSettingsDialog dialog(settings);
-    m_settingsDialog = &dialog;
-    dialog.setWindowTitle(title);
-    connect(this, SIGNAL(dataChanged(TransferItem*, int)), &dialog, SLOT(reject()));
-    
-    if (dialog.exec() == QDialog::Accepted) {
-        submitSettingsResponse(dialog.settings());
-    }
-    else if (status() == AwaitingServiceSettingsResponse) {
-        setErrorString(tr("No settings response"));
-        setStatus(Failed);
-    }
 }
 
 void Transfer::onDecaptchaError(const QString &errorString) {
