@@ -59,9 +59,11 @@ public:
         CanStartRole,
         CaptchaImageRole,
         CaptchaTimeoutRole,
+        CaptchaTimeoutStringRole,
         CategoryRole,
         CreateSubfolderRole,
         CustomCommandRole,
+        CustomCommandOverrideEnabledRole,
         DownloadPathRole,
         ErrorStringRole,
         FileNameRole,
@@ -73,12 +75,17 @@ public:
         PluginIconPathRole,
         PluginIdRole,
         PluginNameRole,
+        PostDataRole,
         PriorityRole,
         PriorityStringRole,
         ProgressRole,
         ProgressStringRole,
         RequestedSettingsRole,
         RequestedSettingsTimeoutRole,
+        RequestedSettingsTimeoutStringRole,
+        RequestedSettingsTitleRole,
+        RequestHeadersRole,
+        RequestMethodRole,
         RowRole,
         RowCountRole,
         SizeRole,
@@ -88,6 +95,7 @@ public:
         StatusStringRole,
         SuffixRole,
         UrlRole,
+        UsePluginsRole,
         WaitTimeRole,
         WaitTimeStringRole
     };
