@@ -405,12 +405,10 @@ TransferItem* TransferModel::get(const QVariant &index) const {
     return get(index.value<QModelIndex>());
 }
 
-void TransferModel::append(const QString &url) {
-    append(url, url.mid(url.lastIndexOf("/") + 1));
-}
-
-void TransferModel::append(const QString &url, const QString &fileName) {
-    Logger::log("TransferModel::append(): " + url + " " + fileName);
+void TransferModel::append(const QString &url, const QString &requestMethod, const QVariantMap &requestHeaders,
+                           const QString &postData) {
+    Logger::log("TransferModel::append(): " + url + " " + requestMethod);
+    const QString fileName = url.mid(url.lastIndexOf("/") + 1);
     TransferItem *package = findPackage(fileName);
 
     if (!package) {
@@ -428,7 +426,11 @@ void TransferModel::append(const QString &url, const QString &fileName) {
     transfer->setDownloadPath(QString("%1.incomplete/%2").arg(Settings::downloadPath()).arg(transferId));
     transfer->setFileName(Utils::getSanitizedFileName(fileName));
     transfer->setId(transferId);
+    transfer->setPostData(postData);
+    transfer->setRequestHeaders(requestHeaders);
+    transfer->setRequestMethod(requestMethod);
     transfer->setUrl(url);
+    transfer->setUsePlugins(false);
 
     beginInsertRows(index(package->row(), 0, QModelIndex()), transferCount, transferCount);
     package->appendRow(transfer);
@@ -441,14 +443,43 @@ void TransferModel::append(const QString &url, const QString &fileName) {
     }
 }
 
-void TransferModel::append(const QStringList &urls) {
+void TransferModel::append(const QStringList &urls, const QString &requestMethod, const QVariantMap &requestHeaders,
+                           const QString &postData) {
     foreach (const QString &url, urls) {
-        append(url);
+        append(url, requestMethod, requestHeaders, postData);
     }
 }
 
 void TransferModel::append(const UrlResult &result) {
-    append(result.url, result.fileName);
+    Logger::log("TransferModel::append(): " + result.url + " " + result.fileName);
+    TransferItem *package = findPackage(result.fileName);
+
+    if (!package) {
+        package = createPackage(result.fileName);
+        const int packageCount = m_packages->rowCount();        
+        beginInsertRows(QModelIndex(), packageCount, packageCount);
+        m_packages->appendRow(package);
+        endInsertRows();
+    }
+
+    const int transferCount = package->rowCount();
+    const QString transferId = Utils::createId();
+    Logger::log("TransferModel::append(): Creating transfer " + transferId);
+    Transfer *transfer = new Transfer(package);
+    transfer->setDownloadPath(QString("%1.incomplete/%2").arg(Settings::downloadPath()).arg(transferId));
+    transfer->setFileName(Utils::getSanitizedFileName(result.fileName));
+    transfer->setId(transferId);
+    transfer->setUrl(result.url);
+
+    beginInsertRows(index(package->row(), 0, QModelIndex()), transferCount, transferCount);
+    package->appendRow(transfer);
+    endInsertRows();
+
+    connect(transfer, SIGNAL(dataChanged(TransferItem*, int)), this, SLOT(onTransferDataChanged(TransferItem*, int)));
+
+    if (Settings::startTransfersAutomatically()) {
+        transfer->queue();
+    }
 }
 
 void TransferModel::append(const UrlResultList &results, const QString &packageName) {
@@ -748,6 +779,8 @@ void TransferModel::onTransferDataChanged(TransferItem *transfer, int role) {
         column = 3;
         emit totalSpeedChanged(totalSpeed());
         break;
+    case TransferItem::CaptchaTimeoutRole:
+    case TransferItem::RequestedSettingsTimeoutRole:
     case TransferItem::WaitTimeRole:
         column = 4;
         break;
@@ -858,6 +891,14 @@ void TransferModel::onTransferStatusChanged(TransferItem *transfer) {
 
         save();
         break;
+    case TransferItem::AwaitingCaptchaResponse:
+        emit captchaRequest(transfer);
+        break;
+    case TransferItem::AwaitingDecaptchaSettingsResponse:
+    case TransferItem::AwaitingRecaptchaSettingsResponse:
+    case TransferItem::AwaitingServiceSettingsResponse:
+        emit settingsRequest(transfer);
+        break;
     default:
         break;
     }
