@@ -34,10 +34,6 @@ UrlCheckDialog::UrlCheckDialog(QWidget *parent) :
 {
     setWindowTitle(tr("Check URLs"));
 
-    if (UrlCheckModel::instance()->status() != UrlCheckModel::Active) {
-        UrlCheckModel::instance()->clear();
-    }
-
     m_view->setModel(UrlCheckModel::instance());
     m_view->setAlternatingRowColors(true);
     m_view->setSelectionBehavior(QTreeView::SelectRows);
@@ -81,11 +77,20 @@ void UrlCheckDialog::addUrls(const QStringList &urls) {
     UrlCheckModel::instance()->append(urls);
 }
 
+void UrlCheckDialog::accept() {
+    clear();
+    QDialog::accept();
+}
+
 void UrlCheckDialog::reject() {
-    UrlCheckModel::instance()->clear();
+    clear();
     QDialog::reject();
 }
 
+void UrlCheckDialog::clear() {
+    UrlCheckModel::instance()->clear();
+}
+
 void UrlCheckDialog::showContextMenu(const QPoint &pos) {
     if (!m_view->currentIndex().isValid()) {
         return;
